@@ -1,4 +1,4 @@
-from .models import *
+from user_action_confirmation.models import *
 from django.contrib import admin
 
 
